@@ -4,11 +4,11 @@ import time
 
 import pytest
 from django.db import connection
+from test_app.tenant.models import DummyModel
 
 from tenant_schemas_celery.test_utils import create_client
-from test_app.tenant.models import DummyModel
 from .compat import get_public_schema_name, schema_context, tenant_context
-from .test_tasks import update_task, update_retry_task, DoesNotExist, get_schema_name, get_schema_from_class_task, SchemaClassLegacyTask
+from .test_tasks import update_task, update_retry_task, DoesNotExist, get_schema_name, get_schema_from_class_task
 
 
 @pytest.fixture
@@ -117,7 +117,7 @@ def test_restoring_schema_name(setup_tenant_test):
 def test_shared_task_get_schema_name(setup_tenant_test):
     result = get_schema_name.delay().get(timeout=1)
     assert result == get_public_schema_name()
-    
+
     with tenant_context(setup_tenant_test["tenant1"]):
         result = get_schema_name.delay().get(timeout=1)
 
@@ -133,7 +133,7 @@ def test_shared_task_get_schema_name(setup_tenant_test):
 def test_custom_task_class_get_schema_name(setup_tenant_test):
     result = get_schema_from_class_task.delay().get(timeout=1)
     assert result == get_public_schema_name()
-    
+
     with tenant_context(setup_tenant_test["tenant1"]):
         result = get_schema_from_class_task.delay().get(timeout=1)
 
@@ -143,18 +143,3 @@ def test_custom_task_class_get_schema_name(setup_tenant_test):
         result = get_schema_from_class_task.delay().get(timeout=1)
 
     assert result == setup_tenant_test["tenant2"].schema_name
-
-
-def test_custom_legacy_task_class_get_schema_name(setup_tenant_test):
-    result = SchemaClassLegacyTask.delay().get(timeout=1)
-    assert result == get_public_schema_name()
-    
-    with tenant_context(setup_tenant_test["tenant1"]):
-        result = SchemaClassLegacyTask.delay().get(timeout=1)
-
-    assert result == setup_tenant_test["tenant1"].schema_name
-
-    with tenant_context(setup_tenant_test["tenant2"]):
-        result = SchemaClassLegacyTask.delay().get(timeout=1)
-
-    assert result == setup_tenant_test["tenant2"].schema_name
